# Horsesale

Horsesale displays the number of horses listed at Japanese horse sales by sire.<p>
To use it, you must fill in the URL from the JBIS Search page. In JBIS Search, the list of horses for sale is uploaded just before the actual day of the sale.<p>
https://www.jbis.or.jp/seri/result/?year=2022&x=68&y=18 <p>

